Duplo - easier tests
====================

Duplo's goal is to provide a set of utilities to easy testing, but presently, it is a toolset for managing the use of `test doubles`_.  An example of a test double is a fake to avoid calling a real URL shortener (like bitly) under test.

Duplo uses `semantic versioning`_.

Contents:

.. toctree::
   :maxdepth: 2

   doubles


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _`test doubles`: http://www.martinfowler.com/bliki/TestDouble.html
.. _`semantic versioning`: http://semver.org
